@@ -24,7 +24,7 @@ DEBUG_MODE_PROGRESS = True
 DEBUG_PRINT = True
 
 
-COPY_CMD_LINE = '-Q -y -v -m 256 -s %s -D -R %s -c %s -Z "*.gz" -Z "*.bz2" -Z "*.zip" ' 
+COPY_CMD_LINE = '-Q -y -v -m 256 -s %s -D -R %s -c %s -Z "*.gz" -Z "*.bz2" -Z "*.zip" '
 COPY_DIFF_CMD_LINE = COPY_CMD_LINE + " -A %s "
 ISOLATE_CMD_LINE = '-Q -v -s %s -A %s -C %s '
 
@@ -109,25 +109,36 @@ class Backup:
         self.diffBackupName = backupName + "-diff-archive"
         self.diffCatalogName = backupName + "-diff-catalog"
         fsMisc.ensure_path(True,target)
-        
 
+        print " BackupEngine: received source path = %s" % sourcePath
+
+        # If the target where we want to store the backup archives
+        # is under a diretory of the sourcePath , then we must ofcourse
+        # exclude it from the nodes dar selects to backup, or otherwise
+        # dar would complain about the possible endless loop effect.
+        if target.startswith(sourcePath):
+            thisExcludePath = "." +  target.replace(sourcePath,'')
+            HUB.EXCLUDE_PATHS.append(thisExcludePath)
+
+        # now make sure we add to the excluded paths the default hubackup
+        # hidden storage folder on a user's respective home folder.
         for myExclPath in HUB.EXCLUDE_PATHS:
             if myExclPath == HUB.TEMP_DIR:
                 myExclPath = myExclPath[1:]
             EX_PATH_CMDLINE += PATH_EXCL_ARG_LINE +  myExclPath
 
         if DEBUG_MODE: print "Excluding: %s" % EX_PATH_CMDLINE
-        self.sliceSizeMB = sliceSizeMB
+        if sliceSizeMB:
+            self.sliceSizeMB = sliceSizeMB
+        else:
+            print "sliceSizeMB was None, maybe implement support for detecting slice sizes inside BackupEngine ?"
+            
         self.sourcePath = sourcePath
         self.target = target
 
         # flag the indicates what was the last backup operation , for cleaning up purpose.
         self.last_backup = "master"
 
-        # set dummy slice size for testing purposes
-        # COMMENT_ME
-        # sliceSizeMB = "28M"
-        
         # each backup phase is suggested as composed of an archiving phase and isloation phase.
         self.BACKUP_CMD_LINE = COPY_CMD_LINE % (sliceSizeMB, sourcePath, target + self.backupName)
 
